==> py-goldsberry-0.8.0.zip: py-goldsberry-0.8.0/goldsberry/_apiparams.py <==
p_base = {
    'LeagueID':'00',
    'Season':'2015-16'
}


p_ply_career = {
    'LeagueID':'00',
    'Season':'2015-16',
    'PerMode':'PerGame'
}

p_ply_gamelogs = {
    'LeagueID':'00',
    'Season':'2015-16',
    'SeasonType':'Regular Season'
}

p_ply_dashboard = {
    'DateFrom':'',
    'DateTo':'',
    'GameSegment':'',
    'LastNGames':0,
    'Location':'',
    'Month':0,
    'OpponentTeamID':0,
    'Outcome':'',
    'Period':0,
    'PerMode':'PerGame',
    'Season':'2015-16',
    'SeasonSegment':'',
    'SeasonType':'Regular Season',
    'TeamID':0,
    'VsConference':'',
    'VsDivision':'',
    'LeagueID':'00'
}

p_ply_list = {
    'IsOnlyCurrentSeason':'1',
    'LeagueID':'00',
    'Season':'2015-16'
}

p_ply_shotchart = {
    'ContextMeasure': 'FGM',
    'DateFrom': '',
    'DateTo': '',
    'GameID': '',
    'GameSegment': '',
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': '',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': '',
    'Period': 0,
    'Position': '',
    'RookieYear': '',
    'Season': '2015-16',
    'SeasonSegment': '',
    'SeasonType': 'Regular Season',
    'TeamID': 0,
    'VsConference': '',
    'VsDivision': ''
    }

p_game_ids = {
    'LeagueID':'00',
    'Season':'2015-16',
    'PlayerOrTeam':'T',
    'Direction':'DESC',
    'SeasonType':'Regular Season',
    'Sorter':'FGM'
}

p_team_lineups = {
    'DateFrom': None,
    'DateTo': None,
    'GameID': None,
    'GameSegment': None,
    'GroupQuantity': 5,
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': None,
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': None,
    'PORound': None,
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': None,
    'SeasonType': 'Regular Season',
    'ShotClockRange': None,
    'VsConference': None,
    'VsDivision': None}

p_team_onoff = {
    'DateFrom': None,
    'DateTo': None,
    'GameSegment': None,
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': None,
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': None,
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': None,
    'SeasonType': 'Regular Season',
    'VsConference': None,
    'VsDivision': None}

p_team_dashbd = {
    'DateFrom': None,
    'DateTo': None,
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': None,
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': None,
    'PerMode': 'Totals',
    'Season': '2015-16',
    'SeasonSegment': None,
    'SeasonType': 'Regular Season',
    'VsConference': None,
    'VsDivision': None
    }

p_team_season = {
    'DateFrom': None,
    'DateTo': None,
    'GameSegment': None,
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': None,
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': None,
    'PORound': None,
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': None,
    'SeasonType': 'Regular Season',
    'ShotClockRange': None,
    'TeamID': 1610612758,
    'VsConference': None,
    'VsDivision': None}

p_team_shooting = {
    'DateFrom': None,
    'DateTo': None,
    'GameSegment': None,
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': None,
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': None,
    'PORound': None,
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': None,
    'SeasonType': 'Regular Season',
    'ShotClockRange': None,
    'VsConference': None,
    'VsDivision': None}

p_team_split = {
    'DateFrom': None,
    'DateTo': None,
    'GameSegment': None,
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': None,
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': None,
    'PORound': None,
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': None,
    'SeasonType': 'Regular Season',
    'ShotClockRange': None,
    'VsConference': None,
    'VsDivision': None}

p_team_info = {
    'LeagueID':'00',
    'Season': '2015-16',
    'SeasonType': 'Pre Season'
    }

p_game_bs = {
    'EndPeriod': 0,
    'EndRange': 0,
    'RangeType': 0,
    'StartPeriod': 0,
    'StartRange': 0}

p_game_pbp = {'EndPeriod': 0, 'StartPeriod': 0}

p_league_sb = {'DayOffset': '0', 'LeagueID': '00'}

p_league_history = {'LeagueID': '00'}

p_league_leaders = {
    'LeagueID':'00',
    'PerMode':'PerGame',
    'Scope':'RS',
    'Season':'2015-16',
    'SeasonType':'Regular Season',
    'StatCategory':'PTS'}

p_league_lineups = {
    'Conference': None,
    'DateFrom': '2016-01-02',
    'DateTo': '2016-01-01',
    'Division': None,
    'GameSegment': None,
    'GroupQuantity': 2,
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': None,
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': None,
    'PORound': None,
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': None,
    'SeasonType': 'Regular Season',
    'ShotClockRange': None,
    'TeamID': None,
    'VsConference': None,
    'VsDivision': None
}

p_league_classic = {
    'College': None,
    'Conference': None,
    'Country': None,
    'DateFrom': None,
    'DateTo': None,
    'Division': None,
    'DraftPick': None,
    'DraftYear': None,
    'GameScope': None,
    'GameSegment': None,
    'Height': None,
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': None,
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': None,
    'PORound': None,
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlayerExperience': None,
    'PlayerPosition': None,
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': None,
    'SeasonType': 'Regular Season',
    'ShotClockRange': None,
    'StarterBench': None,
    'TeamID': None,
    'VsConference': None,
    'VsDivision': None,
    'Weight': None
}

p_league_clutch = {
    'AheadBehind': '',
    'ClutchTime': '',
    'DateFrom': '',
    'DateTo': '',
    'Direction': 'DESC',
    'GameScope': '',
    'GameSegment': '',
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': '',
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': '',
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlayerExperience': '',
    'PlayerOrTeam': 'T',
    'PlayerPosition': '',
    'PlusMinus': 'Y',
    'PointDiff': 0,
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': '',
    'SeasonType': 'Regular Season',
    'Sorter': 'FGM',
    'StarterBench': '',
    'VsConference': '',
    'VsDivision': ''
}

p_draft = {'LeagueID': '00', 'SeasonYear': '2015-16'}

==> py-goldsberry-0.8.0.1.zip: py-goldsberry-0.8.0.1/goldsberry/_apiparams.py <==
p_base = {
    'LeagueID':'00',
    'Season':'2015-16'
}


p_ply_career = {
    'LeagueID':'00',
    'Season':'2015-16',
    'PerMode':'PerGame'
}

p_ply_gamelogs = {
    'LeagueID':'00',
    'Season':'2015-16',
    'SeasonType':'Regular Season'
}

p_ply_dashboard = {
    'DateFrom':'',
    'DateTo':'',
    'GameSegment':'',
    'LastNGames':0,
    'Location':'',
    'Month':0,
    'OpponentTeamID':0,
    'Outcome':'',
    'Period':0,
    'PerMode':'PerGame',
    'Season':'2015-16',
    'SeasonSegment':'',
    'SeasonType':'Regular Season',
    'TeamID':0,
    'VsConference':'',
    'VsDivision':'',
    'LeagueID':'00'
}

p_ply_list = {
    'IsOnlyCurrentSeason':'1',
    'LeagueID':'00',
    'Season':'2015-16'
}

p_ply_shotchart = {
    'ContextMeasure': 'FGM',
    'DateFrom': '',
    'DateTo': '',
    'GameID': '',
    'GameSegment': '',
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': '',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': '',
    'Period': 0,
    'Position': '',
    'RookieYear': '',
    'Season': '2015-16',
    'SeasonSegment': '',
    'SeasonType': 'Regular Season',
    'TeamID': 0,
    'VsConference': '',
    'VsDivision': ''
    }

p_game_ids = {
    'LeagueID':'00',
    'Season':'2015-16',
    'PlayerOrTeam':'T',
    'Direction':'DESC',
    'SeasonType':'Regular Season',
    'Sorter':'FGM'
}

p_team_lineups = {
    'DateFrom': '',
    'DateTo': '',
    'GameID': '',
    'GameSegment': '',
    'GroupQuantity': 5,
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': '',
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': '',
    'PORound': '',
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': '',
    'SeasonType': 'Regular Season',
    'ShotClockRange': '',
    'VsConference': '',
    'VsDivision': ''}

p_team_onoff = {
    'DateFrom': '',
    'DateTo': '',
    'GameSegment': '',
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': '',
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': '',
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': '',
    'SeasonType': 'Regular Season',
    'VsConference': '',
    'VsDivision': ''}

p_team_dashbd = {
    'DateFrom': '',
    'DateTo': '',
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': '',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': '',
    'PerMode': 'Totals',
    'Season': '2015-16',
    'SeasonSegment': '',
    'SeasonType': 'Regular Season',
    'VsConference': '',
    'VsDivision': ''
    }

p_team_season = {
    'DateFrom': '',
    'DateTo': '',
    'GameSegment': '',
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': '',
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': '',
    'PORound': '',
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': '',
    'SeasonType': 'Regular Season',
    'ShotClockRange': '',
    'TeamID': 1610612758,
    'VsConference': '',
    'VsDivision': ''}

p_team_shooting = {
    'DateFrom': '',
    'DateTo': '',
    'GameSegment': '',
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': '',
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': '',
    'PORound': '',
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': '',
    'SeasonType': 'Regular Season',
    'ShotClockRange': '',
    'VsConference': '',
    'VsDivision': ''}

p_team_split = {
    'DateFrom': '',
    'DateTo': '',
    'GameSegment': '',
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': '',
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': '',
    'PORound': '',
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': '',
    'SeasonType': 'Regular Season',
    'ShotClockRange': '',
    'VsConference': '',
    'VsDivision': ''}

p_team_info = {
    'LeagueID':'00',
    'Season': '2015-16',
    'SeasonType': 'Pre Season'
    }

p_game_bs = {
    'EndPeriod': 0,
    'EndRange': 0,
    'RangeType': 0,
    'StartPeriod': 0,
    'StartRange': 0}

p_game_pbp = {'EndPeriod': 0, 'StartPeriod': 0}

p_league_sb = {'DayOffset': '0', 'LeagueID': '00'}

p_league_history = {'LeagueID': '00'}

p_league_leaders = {
    'LeagueID':'00',
    'PerMode':'PerGame',
    'Scope':'RS',
    'Season':'2015-16',
    'SeasonType':'Regular Season',
    'StatCategory':'PTS'}

p_league_lineups = {
    'Conference': '',
    'DateFrom': '2016-01-02',
    'DateTo': '2016-01-01',
    'Division': '',
    'GameSegment': '',
    'GroupQuantity': 2,
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': '',
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': '',
    'PORound': '',
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': '',
    'SeasonType': 'Regular Season',
    'ShotClockRange': '',
    'TeamID': '',
    'VsConference': '',
    'VsDivision': ''
}

p_league_classic = {
    'College': '',
    'Conference': '',
    'Country': '',
    'DateFrom': '',
    'DateTo': '',
    'Division': '',
    'DraftPick': '',
    'DraftYear': '',
    'GameScope': '',
    'GameSegment': '',
    'Height': '',
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': '',
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': '',
    'PORound': '',
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlayerExperience': '',
    'PlayerPosition': '',
    'PlusMinus': 'Y',
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': '',
    'SeasonType': 'Regular Season',
    'ShotClockRange': '',
    'StarterBench': '',
    'TeamID': '',
    'VsConference': '',
    'VsDivision': '',
    'Weight': ''
}

p_league_clutch = {
    'AheadBehind': '',
    'ClutchTime': '',
    'DateFrom': '',
    'DateTo': '',
    'Direction': 'DESC',
    'GameScope': '',
    'GameSegment': '',
    'LastNGames': 0,
    'LeagueID': '00',
    'Location': '',
    'MeasureType': 'Base',
    'Month': 0,
    'OpponentTeamID': 0,
    'Outcome': '',
    'PaceAdjust': 'Y',
    'PerMode': 'Totals',
    'Period': 0,
    'PlayerExperience': '',
    'PlayerOrTeam': 'T',
    'PlayerPosition': '',
    'PlusMinus': 'Y',
    'PointDiff': 0,
    'Rank': 'Y',
    'Season': '2015-16',
    'SeasonSegment': '',
    'SeasonType': 'Regular Season',
    'Sorter': 'FGM',
    'StarterBench': '',
    'VsConference': '',
    'VsDivision': ''
}

p_draft = {'LeagueID': '00', 'SeasonYear': '2015-16'}
